pub struct OfferBrief {
pub words: String,
pub act: PendingAct,
}Expand description
A next step the last reply offered: taken up, it is this act, on its record, with the values it already has; the words are those the reply offered it in.
Fields
words: StringThe words the reply offered it in.
act: PendingActThe act it runs.
Implementations
Sourceimpl OfferBrief
impl OfferBrief
Sourcepub fn new(words: impl Into<String>, act: PendingAct) -> Self
pub fn new(words: impl Into<String>, act: PendingAct) -> Self
An offer of act, made in words.