pub struct Words { /* private fields */ }Expand description
A message split into numbered words.
Implementations
Sourceimpl Words
impl Words
Sourcepub fn narrow(&self, span: Span, copied: &str) -> Option<Span>
pub fn narrow(&self, span: Span, copied: &str) -> Option<Span>
The words inside span that copied repeats, compared without case and without
the punctuation at either end of a word; None when they are not there.
Sourcepub fn only_place(&self, copied: &str) -> Option<Span>
pub fn only_place(&self, copied: &str) -> Option<Span>
Where in the whole message copied is repeated, when it is repeated in one place only.